From 87b69ef1025986168add56b55b034f1e8beb5288 Mon Sep 17 00:00:00 2001
From: Sergey Fedorov <vital.had@gmail.com>
Date: Tue, 11 Apr 2023 06:27:04 +0800
Subject: [PATCH] loguru: fix for missing pthread_is_threaded_np

---
 thirdparty/loguru/loguru.cpp | 12 +++++++++++-
 1 file changed, 11 insertions(+), 1 deletion(-)

diff --git a/thirdparty/loguru/loguru.cpp b/thirdparty/loguru/loguru.cpp
index affe3b90..90110d8e 100644
--- thirdparty/loguru/loguru.cpp
+++ thirdparty/loguru/loguru.cpp
@@ -1084,7 +1084,17 @@ namespace loguru
 
 			#ifdef __APPLE__
 				uint64_t thread_id;
-				pthread_threadid_np(pthread_self(), &thread_id);
+				#if MAC_OS_X_VERSION_MAX_ALLOWED < 1060 || defined __POWERPC__
+				    thread_id = pthread_mach_thread_np(pthread_self());
+				#elif MAC_OS_X_VERSION_MIN_REQUIRED < 1060
+				    if (&pthread_threadid_np) {
+				        pthread_threadid_np(pthread_self(), &thread_id);
+				    } else {
+				        thread_id = pthread_mach_thread_np(pthread_self());
+				    }
+				#else
+				    pthread_threadid_np(pthread_self(), &thread_id);
+				#endif
 			#elif defined(__FreeBSD__)
 				long thread_id;
 				(void)thr_self(&thread_id);
